@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.2.6
+# Version   : 0.2.8
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -195,6 +195,8 @@ class AFM:
         self.approach_raw = []
         self.retract_raw = []
         self.z_position_raw = []
+        self.z_approach_raw = []
+        self.z_withdraw_raw = []
 
         self.adhesion = []
         self.modulus = []
@@ -211,6 +213,7 @@ class AFM:
         self.file_name = []
         self.filelist = []
         self.run_name = []
+        self.measurements = []
 
 
     def set_run_name(self,_run_name):
@@ -445,6 +448,8 @@ class AFM:
 
             i += 1
 
+        self.measurements = self.approach_raw.shape[1]
+
 
     def nanosurf_import(
         self
@@ -471,8 +476,14 @@ class AFM:
 
         self.approach_raw = np.array(_approach, dtype=object)
         self.retract_raw = np.array(_withdraw, dtype=object)
-        self.z_approach = np.array(_z_approach, dtype=object)
-        self.z_withdraw = np.array(_z_withdraw, dtype=object)
+        self.z_approach_raw = np.array(_z_approach, dtype=object)
+        self.z_withdraw_raw = np.array(_z_withdraw, dtype=object)
+
+        self.measurements = self.approach_raw.shape[0]
+
+        list_len = [len(i) for i in self.approach_raw]
+
+            
 
     def plot_raw(
         self,
@@ -494,8 +505,8 @@ class AFM:
 
         else:
             fig = go.Figure()
-            fig.add_trace(go.Scatter(y = self.approach_raw[:,curve_number], x = self.z_approach[:,curve_number], mode='lines', name = 'Approach curve (raw)'))
-            fig.add_trace(go.Scatter(y = self.retract_raw[:,curve_number], x = self.z_withdraw[:,curve_number], mode='lines', name = 'Retract curve (raw)'))
+            fig.add_trace(go.Scatter(y = self.approach_raw[:,curve_number], x = self.z_approach_raw[:,curve_number], mode='lines', name = 'Approach curve (raw)'))
+            fig.add_trace(go.Scatter(y = self.retract_raw[:,curve_number], x = self.z_withdraw_raw[:,curve_number], mode='lines', name = 'Retract curve (raw)'))
             fig.update_layout(
                 yaxis_title_text='Force (nN)',
                 xaxis_title_text='Piezo position (nm)',
@@ -527,10 +538,15 @@ class AFM:
 
         i = 0
         
-        for curve_number in range(0, self.approach_raw.shape[1]):
+        for curve_number in range(0, self.measurements):
 
-            _approach = self.approach_raw[:,curve_number]
-            _retract = self.retract_raw[:,curve_number]
+            if self.file_name[-3:] != 'nid':
+                _approach = self.approach_raw[:,curve_number]
+                _retract = self.retract_raw[:,curve_number]
+            else:
+                _approach = self.approach_raw[curve_number]
+                _retract = self.retract_raw[curve_number]
+                
 
             baseline_start = int(len(_approach) * start_pos)
             baseline_end = int(len(_approach) * end_pos)
@@ -549,6 +565,18 @@ class AFM:
 
             if self.file_name[-3:] != 'nid':
                 _z = self.z_position_raw[:,curve_number]
+            else:
+                _z_a = self.z_approach_raw[curve_number]
+                _z_w = self.z_withdraw_raw[curve_number]
+
+            if len(adjusted_approach) < self.samps_line:
+                blank = np.empty(self.samps_line - len(adjusted_approach))
+                blank[:] = np.nan
+
+                adjusted_approach = np.append(adjusted_approach, blank)
+                adjusted_retract =  np.append(adjusted_retract, blank)
+                _z_a = np.append(_z_a, blank)
+                _z_w = np.append(_z_w, blank)
 
             if approach_dev < max_approach_noise and retract_dev < max_retract_noise:
                 self.approach[:,i] = adjusted_approach
@@ -558,6 +586,10 @@ class AFM:
                     self.z_approach[:,i] = _z
                     self.z_withdraw[:,i] = _z
 
+                else:
+                    self.z_approach[:,i] = _z_a
+                    self.z_withdraw[:,i] = _z_w
+
                 i += 1
 
         self.approach = self.approach[:,:i]
@@ -755,7 +787,8 @@ class AFM:
             def_sens = self.def_sens,
             spr_const = self.spr_const,
             file_name = self.file_name,
-            run_name = self.run_name
+            run_name = self.run_name,
+            measurements = self.measurements
         )
 
     def load_data(
@@ -790,6 +823,7 @@ class AFM:
         self.spr_const = data['spr_const']
         self.file_name = data['file_name']
         self.run_name = data['run_name']
+        self.measurements = data['measurements']
 
     def calc_adhesion(
         self,
